================================================================================
 `xoutil.eight`:mod: -- Extensions for writing code that runs on Python 2 and 3
================================================================================

.. module:: xoutil.eight

.. deprecated:: 2.0.6 This module only serves to write programs that run the
   same in Python 2 and 3.  But 'xoutil>=2' works in Python 3 only.

The name comes from (Manu's idea') "2 raised to the power of 3".

This module is divided in several parts.

.. toctree::
   :glob:

   eight/abc
   eight/meta
   eight/mixins
   eight/string
   eight/text
   eight/io
   eight/queue
   eight/exceptions
